tcgl: code.google.com/p/tcgl/sort Index | Files

package sort

import "code.google.com/p/tcgl/sort"

The sort package provides a parallel quicksort.

It uses the same interface as the standard sort package.

Index

func Sort

func Sort(data sort.Interface)

Sort is the single function for sorting data according to the standard sort interface. Internally it uses the parallel quicksort.

Files

doc.go sort.go

Package sort imports 2 packages (graph). Updated 2013-04-04. Refresh.