import "code.google.com/p/tcgl/sort"
The sort package provides a parallel quicksort.
It uses the same interface as the standard sort package.
func Sort(data sort.Interface)
Sort is the single function for sorting data according to the standard sort interface. Internally it uses the parallel quicksort.